@@ -4,21 +4,30 @@
 #'
 #' @param variable a numeric vector.
 #' @param h integer; 1 (default) Number of periods to forecast.
-#' @param training.set numeric; \code{NULL} (defualt) Sets the number of variable observations \code{(variable[1:training.set])} to monitor performance of forecast over in-sample range.
+#' @param training.set numeric; \code{NULL} (defualt) Sets the number of variable observations
+#'  \code{(variable[1:training.set])} to monitor performance of forecast over in-sample range.
 #' @param seasonal.factor logical or integer(s); \code{TRUE} (default) Automatically selects the best seasonal lag from the seasonality test.  To use weighted average of all seasonal lags set to \code{(seasonal.factor=FALSE)}.  Otherwise, directly input known frequency integer lag to use, i.e. \code{(seasonal.factor=12)} for monthly data.  Multiple frequency integers can also be used, i.e. \code{(seasonal.factor=c(12,24,36))}
-#' @param best.periods integer; to be used in conjuction with \code{(seasonal.factor=FALSE)}, uses the \code{best.periods} number of detected seasonal lags instead of \code{ALL} lags when \code{(seasonal.factor=FALSE)}.
-#' @param negative.values logical; \code{FALSE} (default) If the variable can be negative, set to \code{(negative.values=TRUE)}.
-#' @param method options: ("lin","nonlin","both"); \code{"nonlin"} (default)  To select the regression type of the component series, select \code{(method="both")} where both linear and nonlinear estimates are generated.  To use a nonlineaer regression, set to \code{(method="nonlin")}; to use a linear regression set to \code{(method="lin")}.
+#' @param best.periods integer; to be used in conjuction with \code{(seasonal.factor=FALSE)}, uses the \code{best.periods} number of detected seasonal lags instead of \code{ALL} lags when
+#' \code{(seasonal.factor=FALSE)}.
+#' @param negative.values logical; \code{FALSE} (default) If the variable can be negative, set to
+#' \code{(negative.values=TRUE)}.
+#' @param method options: ("lin","nonlin","both"); \code{"nonlin"} (default)  To select the regression type of the component series, select \code{(method="both")} where both linear and nonlinear estimates are generated.  To use a nonlineaer regression, set to
+#' \code{(method="nonlin")}; to use a linear regression set to \code{(method="lin")}.
 #' @param dynamic logical; \code{FALSE} (default) To update the seasonal factor with each forecast point, set to \code{(dynamic=TRUE)}.  The default is \code{(dynamic=FALSE)} to retain the original seasonal factor from the inputted variable for all ensuing \code{h}.
 #' @param plot logical; \code{TRUE} (default) Returns the plot of all periods exhibiting seasonality and the \code{variable} level reference in upper panel.  Lower panel returns original data and forecast.
 #' @param seasonal.plot logical; \code{TRUE} (default) Adds the seasonality plot above the forecast.  Will be set to \code{FALSE} if no seasonality is detected or \code{seasonal.factor} is set to an integer value.
 #' @param intervals logical; \code{FALSE} (default) Plots the surrounding forecasts around the final estimate when \code{(intervals=TRUE)} and \code{(seasonal.factor=FALSE)}.  There are no other forecasts to plot when a single \code{seasonal.factor} is selected.
 #' @return Returns a vector of forecasts of length \code{(h)}.
-#' @note \code{(seasonal.factor=FALSE)} can be a very comutationally expensive exercise due to the number of seasonal periods detected.
+#' @note
+#' For monthly data series, increased accuracy may be realized from forcing seasonal factors to multiples of 12.  For example, if the best periods reported are: \{37, 47, 71, 73\}  use
+#' \code{(seasonal.factor=c(36,48,72))}.
+#'
+#' \code{(seasonal.factor=FALSE)} can be a very comutationally expensive exercise due to the number of seasonal periods detected.
 #'
 #' If error encountered when \code{(seasonal.factor=TRUE)}:
 #'
-#' \code{"NaNs produced Error in seq.default(length(variable)+1, 1, -lag[i]) : wrong sign in 'by' argument"}
+#' \code{"NaNs produced Error in seq.default(length(variable)+1, 1, -lag[i]) :
+#'  wrong sign in 'by' argument"}
 #'
 #' use the combination of \code{(seasonal.factor=FALSE, best.periods=1)}.
 #'
@@ -92,13 +101,13 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,b
     }
 
 }}
-  #Vectors generator for 1:lag
-  generate.vectors=function(lag,j){
+  # Generator for 1:length(lag) vectors
+  generate.vectors=function(l){
     Component.series = list()
     Component.index = list()
 
-    for (i in 1:length(lag)){
-      CS=rev(variable[seq(length(variable)+1,1,-lag[i])])
+    for (i in 1:length(l)){
+      CS=rev(variable[seq(length(variable)+1,1,-l[i])])
       CS=CS[!is.na(CS)]
       Component.series[[paste('Series.',i,sep="")]] <- CS
       Component.index[[paste('Index.',i,sep="")]] <- (1:length(CS))
@@ -132,7 +141,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,b
 
       if(method=='nonlin' | method=='both'){
 
-          Regression.Estimates=sapply(1:length(lag),function(i) NNS.reg(Component.index[[i]],Component.series[[i]],point.est = (length(Component.series[[i]])+1),return.values = TRUE,order = NULL,plot = FALSE,stn=0)$Point.est)
+          Regression.Estimates=sapply(1:length(lag),function(i) NNS.reg(Component.index[[i]],Component.series[[i]],point.est = (length(Component.series[[i]])+1),return.values = FALSE,order = NULL,plot = FALSE,stn=0)$Point.est)
 
         if(negative.values==FALSE){
           Regression.Estimates=pmax(0,Regression.Estimates)
@@ -143,7 +152,11 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,b
 
       if(method=='lin' | method=='both'){
 
-          Regression.Estimates=sapply(1:length(lag),function(i) coef(lm(Component.series[[i]]~Component.index[[i]]))[1]+(coef(lm(Component.series[[i]]~Component.index[[i]]))[2]*(length(Component.series[[i]])+1)))
+        for(i in 1:length(lag)){
+          coefs=coef(lm(Component.series[[i]]~Component.index[[i]]))
+          Regression.Estimates[[i]]=coefs[1]+(coefs[2]*(length(Component.series[[i]])+1))
+        }
+
         if(negative.values==FALSE){
           Regression.Estimates=pmax(0,Regression.Estimates)
         }
@@ -202,7 +215,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,b
 
     for (j in 0:(h-1)){
       # Generate vectors for 1:lag
-      GV=generate.vectors(lag,j)
+      GV=generate.vectors(lag)
       Component.index=GV$Component.index
       Component.series=GV$Component.series
 
@@ -212,7 +225,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,b
 
       if(method=='nonlin' | method=='both'){
 
-          Regression.Estimates=sapply(1:length(lag),function(i) NNS.reg(Component.index[[i]],Component.series[[i]],point.est = (length(Component.series[[i]])+1),return.values = TRUE,order = NULL,plot = FALSE,stn=0,noise.reduction = 'off')$Point.est)
+          Regression.Estimates=sapply(1:length(lag),function(i) NNS.reg(Component.index[[i]],Component.series[[i]],point.est = (length(Component.series[[i]])+1),return.values = FALSE,order = NULL,plot = FALSE,stn=0,noise.reduction = 'off')$Point.est)
 
         if(negative.values==FALSE){
           Regression.Estimates=pmax(0,Regression.Estimates)
@@ -220,11 +233,15 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,b
 
         NL.Regression.Estimates=Regression.Estimates
         Nonlin.estimates=sum(Regression.Estimates*Weights)
+
       }#Linear == F
 
       if(method=='lin' | method=='both'){
 
-          Regression.Estimates=sapply(1:length(lag),function(i) coef(lm(Component.series[[i]]~Component.index[[i]]))[1]+(coef(lm(Component.series[[i]]~Component.index[[i]]))[2]*(length(Component.series[[i]])+1)))
+        for(i in 1:length(lag)){
+          coefs=coef(lm(Component.series[[i]]~Component.index[[i]]))
+          Regression.Estimates[i] = coefs[1] + (coefs[2]*(length(Component.series[[i]])+1))
+        }
 
         if(negative.values==FALSE){
           Regression.Estimates=pmax(0,Regression.Estimates)
@@ -277,7 +294,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,b
     }
     label=names(variable)
     if(is.null(label)){label = "Variable"}
-    plot(OV, type = 'l',lwd=2,main = "Forecast",col='steelblue',
+    plot(OV, type = 'l',lwd=2,main = "NNS.ARMA Forecast",col='steelblue',
           xlim=c(1,max((training.set+h),length(OV))),
           ylab=label, ylim=c(min(Estimates, OV),max( OV,Estimates)))
 
